import matplotlib.pyplot as plt
import pandas

# Lecture des donnees
entites = pandas.read_csv('entity.csv', sep = ',')
executeurs = pandas.read_csv('officer.csv', sep = ',')
adresses = pandas.read_csv('address.csv', sep = ',')
liens = pandas.read_csv('edges.csv', sep = ',')
geographie = pandas.read_csv('geo_papers.csv', sep = ',', decimal = ',')

# Pays impliques
paradis = entites['n.countries'].value_counts()
pays_executeurs = executeurs['n.countries'].value_counts()
pays_clients = adresses['n.countries'].value_counts()

# Représentation des pays impliques

# 1. Ajout de nouvelles colonnes au dataframe geographie
col1 = []
for pays in geographie['state'] :
    if pays in paradis.index.values :
        col1.append(paradis[pays])
    else :
        col1.append(0)
col2 = []
for pays in geographie['state'] :
    if pays in pays_executeurs.index.values :
        col2.append(pays_executeurs[pays])
    else :
        col2.append(0)
col3 = []
for pays in geographie['state'] :
    if pays in pays_clients.index.values :
        col3.append(pays_clients[pays])
    else :
        col3.append(0)
geographie['nb paradis'] = col1
geographie['nb executeurs'] = col2
geographie['nb clients'] = col3
col4 = geographie.apply(lambda row : row['nb paradis'] + row['nb executeurs'] + row['nb clients'], axis = 1)
geographie['poids'] = col4

# 2. Carte des paradis fiscaux
import folium
carte_paradis = folium.Map(location = [0, 0], zoom_start = 2, tiles = 'Stamen Terrain')

from math import sqrt, pi
for k in geographie.index.values :
    latitude = geographie.loc[k, 'latitude']
    longitude = geographie.loc[k, 'longitude']
    rayon = sqrt(geographie.loc[k, 'poids']/(10 * pi))
    folium.CircleMarker([latitude, longitude], radius = rayon).add_to(carte_paradis)

carte_paradis.save('C:/Users/dutar/Desktop/carte_paradis.html')

# 3. Representation des liens sur une carte
carte_liens = folium.Map(location=[0,0],zoom_start = 2,tiles='Stamen Terrain')

for k in range(10000):
    # On cherche dans les 3 fichiers executeurs, adresses
    # et entites, le pays correspondant au noeud 1
    # reset_index(drop = True) permet de reinitialiser l'index
    noeud1 = liens.loc[k,'node_1']
    try :
        if executeurs[executeurs['n.node_id'] == noeud1]['n.countries'].empty == False:
            pays1 = executeurs[executeurs['n.node_id'] == noeud1]['n.countries'].reset_index(drop = True)
        elif adresses[adresses['n.node_id'] == noeud1]['n.countries'].empty == False:
            pays1 = adresses[adresses['n.node_id'] == noeud1]['n.countries'].reset_index(drop = True)
        elif entites[entites['n.node_id'] == noeud1]['n.countries'].empty == False:
            pays1 = entites[entites['n.node_id'] == noeud1]['n.countries'].reset_index(drop = True)
        pays1 = pays1[0] 
    except:
        pays1 = ''
    # si le pays 1 est dans le fichier geographie, on cherche
    # dans les 3 fichiers le pays correspondant au noeud 2
    if geographie[geographie['state']== pays1].empty == False:
        noeud2 = liens.loc[k,'node_2']
        try:
            if executeurs[executeurs['n.node_id'] == noeud2]['n.countries'].empty == False:
                pays2 = executeurs[executeurs['n.node_id'] == noeud2]['n.countries'].reset_index(drop = True)
            elif adresses[adresses['n.node_id'] == noeud2]['n.countries'].empty == False:
                pays2 = adresses[adresses['n.node_id'] == noeud2]['n.countries'].reset_index(drop = True)
            elif entites[entites['n.node_id'] == noeud2]['n.countries'].empty == False:
                pays2 = entites[entites['n.node_id'] == noeud2]['n.countries'].reset_index(drop = True)
            pays2 = pays2[0]
        except:
            pays2 = ''
    # Si les pays 1 et 2 sont dans le fichier geographie, on
    # recupere leur latitude et longitude et on les relie 
    if geographie[geographie['state']== pays1].empty == False:
        if geographie[geographie['state']== pays2].empty == False:
            pays = geographie[geographie['state']== pays1].reset_index(drop = True)
            lat1 = pays['latitude'][0]
            long1 = pays['longitude'][0]
            pays = geographie[geographie['state']== pays2].reset_index(drop = True)
            lat2 = pays['latitude'][0]
            long2 = pays['longitude'][0]
            folium.PolyLine([[lat1,long1],[lat2,long2]], color='red').add_to(carte_liens)
    
carte_liens.save('C:/Users/dutar/Desktop/carte_liens.html')
